@@ -1,20 +1,16 @@
 package v1
 
 import (
-	"context"
-
 	"github.com/RHsyseng/operator-utils/pkg/olm"
 	oappsv1 "github.com/openshift/api/apps/v1"
 	buildv1 "github.com/openshift/api/build/v1"
 	oimagev1 "github.com/openshift/api/image/v1"
 	routev1 "github.com/openshift/api/route/v1"
-	imagev1 "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"sigs.k8s.io/controller-runtime/pkg/client"
 )
 
 // EDIT THIS FILE!  THIS IS SCAFFOLDING FOR YOU TO OWN!
@@ -486,18 +482,6 @@ type KieAppStatus struct {
 	Deployments olm.DeploymentStatus `json:"deployments"`
 }
 
-type PlatformService interface {
-	Create(ctx context.Context, obj runtime.Object) error
-	Delete(ctx context.Context, obj runtime.Object, opts ...client.DeleteOptionFunc) error
-	Get(ctx context.Context, key client.ObjectKey, obj runtime.Object) error
-	List(ctx context.Context, opts *client.ListOptions, list runtime.Object) error
-	Update(ctx context.Context, obj runtime.Object) error
-	GetCached(ctx context.Context, key client.ObjectKey, obj runtime.Object) error
-	ImageStreamTags(namespace string) imagev1.ImageStreamTagInterface
-	GetScheme() *runtime.Scheme
-	IsMockService() bool
-}
-
 func init() {
 	SchemeBuilder.Register(&KieApp{}, &KieAppList{})
 }
