@@ -32,6 +32,7 @@ type KieAppSpec struct {
 	Auth          KieAppAuthObject `json:"auth,omitempty"`
 	Upgrades      KieAppUpgrades   `json:"upgrades,omitempty"`
 	Version       string           `json:"version,omitempty"`
+	UseImageTags  bool             `json:"useImageTags"`
 }
 
 // EnvironmentType describes a possible application environment
@@ -71,6 +72,7 @@ type AppConstants struct {
 	Product   string `json:"name,omitempty"`
 	Prefix    string `json:"prefix,omitempty"`
 	ImageName string `json:"imageName,omitempty"`
+	ImageVar  string `json:"imageVar,omitempty"`
 	MavenRepo string `json:"mavenRepo,omitempty"`
 }
 
@@ -84,6 +86,7 @@ type KieAppRegistry struct {
 
 // KieApp is the Schema for the kieapps API
 // +k8s:openapi-gen=true
+// +kubebuilder:resource:path=kieapps,scope=Namespaced
 type KieApp struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty"`
@@ -128,6 +131,7 @@ type KieServerSet struct {
 	KieAppObject `json:",inline"`
 	Database     *DatabaseObject  `json:"database,omitempty"`
 	Jms          *KieAppJmsObject `json:"jms,omitempty"`
+	Jvm          *JvmObject       `json:"jvm,omitempty"`
 }
 
 // ConsoleObject Console deployment object
@@ -135,8 +139,10 @@ type ConsoleObject struct {
 	KieAppObject `json:",inline"`
 	SSOClient    *SSOAuthClient  `json:"ssoClient,omitempty"`
 	GitHooks     *GitHooksVolume `json:"gitHooks,omitempty"`
+	Jvm          *JvmObject      `json:"jvm,omitempty"`
 }
 
+// SmartRouterObject deployment object
 type SmartRouterObject struct {
 	KieAppObject     `json:",inline"`
 	Protocol         string `json:"protocol,omitempty"`
@@ -167,6 +173,23 @@ type KieAppJmsObject struct {
 	AMQEnableSSL          bool   `json:"amqEnableSSL,omitempty"` // flag will be set to true if all AMQ SSL parameters are correctly set.
 }
 
+// JvmObject JVM specification to be used by the KieApp
+type JvmObject struct {
+	JavaOptsAppend             string `json:"javaOptsAppend,omitempty"`
+	JavaMaxMemRatio            *int32 `json:"javaMaxMemRatio,omitempty"`
+	JavaInitialMemRatio        *int32 `json:"javaInitialMemRatio,omitempty"`
+	JavaMaxInitialMem          *int32 `json:"javaMaxInitialMem,omitempty"`
+	JavaDiagnostics            *bool  `json:"javaDiagnostics,omitempty"`
+	JavaDebug                  *bool  `json:"javaDebug,omitempty"`
+	JavaDebugPort              *int32 `json:"javaDebugPort,omitempty"`
+	GcMinHeapFreeRatio         *int32 `json:"gcMinHeapFreeRatio,omitempty"`
+	GcMaxHeapFreeRatio         *int32 `json:"gcMaxHeapFreeRatio,omitempty"`
+	GcTimeRatio                *int32 `json:"gcTimeRatio,omitempty"`
+	GcAdaptiveSizePolicyWeight *int32 `json:"gcAdaptiveSizePolicyWeight,omitempty"`
+	GcMaxMetaspaceSize         *int32 `json:"gcMaxMetaspaceSize,omitempty"`
+	GcContainerOptions         string `json:"gcContainerOptions,omitempty"`
+}
+
 // KieAppObject Generic object definition
 type KieAppObject struct {
 	Env            []corev1.EnvVar             `json:"env,omitempty"`
@@ -201,12 +224,15 @@ type CustomObject struct {
 
 // KieAppBuildObject Data to define how to build an application from source
 type KieAppBuildObject struct {
-	KieServerContainerDeployment string                  `json:"kieServerContainerDeployment,omitempty"`
-	GitSource                    GitSource               `json:"gitSource,omitempty"`
-	MavenMirrorURL               string                  `json:"mavenMirrorURL,omitempty"`
-	ArtifactDir                  string                  `json:"artifactDir,omitempty"`
-	Webhooks                     []WebhookSecret         `json:"webhooks,omitempty"`
-	From                         *corev1.ObjectReference `json:"from,omitempty"`
+	KieServerContainerDeployment     string                  `json:"kieServerContainerDeployment,omitempty"`
+	GitSource                        GitSource               `json:"gitSource,omitempty"`
+	MavenMirrorURL                   string                  `json:"mavenMirrorURL,omitempty"`
+	ArtifactDir                      string                  `json:"artifactDir,omitempty"`
+	Webhooks                         []WebhookSecret         `json:"webhooks,omitempty"`
+	From                             *corev1.ObjectReference `json:"from,omitempty"`
+	ExtensionImageStreamTag          string                  `json:"extensionImageStreamTag,omitempty"`
+	ExtensionImageStreamTagNamespace string                  `json:"extensionImageStreamTagNamespace,omitempty"`
+	ExtensionImageInstallDir         string                  `json:"extensionImageInstallDir,omitempty"`
 }
 
 // GitSource Git coordinates to locate the source code to build
@@ -371,47 +397,60 @@ type TemplateConstants struct {
 	MavenRepo            string `json:"mavenRepo,omitempty"`
 	KeystoreVolumeSuffix string `json:"keystoreVolumeSuffix"`
 	DatabaseVolumeSuffix string `json:"databaseVolumeSuffix"`
+	OseCliImageURL       string `json:"oseCliImageURL,omitempty"`
 	BrokerImage          string `json:"brokerImage"`
 	BrokerImageTag       string `json:"brokerImageTag"`
 	DatagridImage        string `json:"datagridImage"`
 	DatagridImageTag     string `json:"datagridImageTag"`
+	MySQLImageURL        string `json:"mySQLImageURL"`
+	PostgreSQLImageURL   string `json:"postgreSQLImageURL"`
+	BrokerImageURL       string `json:"brokerImageURL,omitempty"`
+	DatagridImageURL     string `json:"datagridImageURL,omitempty"`
 	RoleMapperVolume     string `json:"roleMapperVolume"`
 	GitHooksVolume       string `json:"gitHooksVolume,omitempty"`
 }
 
 // ConsoleTemplate contains all the variables used in the yaml templates
 type ConsoleTemplate struct {
-	SSOAuthClient  SSOAuthClient  `json:"ssoAuthClient,omitempty"`
-	Name           string         `json:"name,omitempty"`
-	Replicas       int32          `json:"replicas,omitempty"`
-	Image          string         `json:"image,omitempty"`
-	ImageTag       string         `json:"imageTag,omitempty"`
-	KeystoreSecret string         `json:"keystoreSecret,omitempty"`
-	GitHooks       GitHooksVolume `json:"gitHooks,omitempty"`
+	OmitImageStream bool           `json:"omitImageStream"`
+	SSOAuthClient   SSOAuthClient  `json:"ssoAuthClient,omitempty"`
+	Name            string         `json:"name,omitempty"`
+	Replicas        int32          `json:"replicas,omitempty"`
+	Image           string         `json:"image,omitempty"`
+	ImageTag        string         `json:"imageTag,omitempty"`
+	ImageURL        string         `json:"imageURL,omitempty"`
+	KeystoreSecret  string         `json:"keystoreSecret,omitempty"`
+	GitHooks        GitHooksVolume `json:"gitHooks,omitempty"`
+	Jvm             JvmObject      `json:"jvm,omitempty"`
 }
 
 // ServerTemplate contains all the variables used in the yaml templates
 type ServerTemplate struct {
-	KieName        string                 `json:"kieName,omitempty"`
-	KieServerID    string                 `json:"kieServerID,omitempty"`
-	Replicas       int32                  `json:"replicas,omitempty"`
-	SSOAuthClient  SSOAuthClient          `json:"ssoAuthClient,omitempty"`
-	From           corev1.ObjectReference `json:"from,omitempty"`
-	Build          BuildTemplate          `json:"build,omitempty"`
-	KeystoreSecret string                 `json:"keystoreSecret,omitempty"`
-	Database       DatabaseObject         `json:"database,omitempty"`
-	Jms            KieAppJmsObject        `json:"jms,omitempty"`
-	SmartRouter    SmartRouterObject      `json:"smartRouter,omitempty"`
+	OmitImageStream bool                   `json:"omitImageStream"`
+	KieName         string                 `json:"kieName,omitempty"`
+	KieServerID     string                 `json:"kieServerID,omitempty"`
+	Replicas        int32                  `json:"replicas,omitempty"`
+	SSOAuthClient   SSOAuthClient          `json:"ssoAuthClient,omitempty"`
+	From            corev1.ObjectReference `json:"from,omitempty"`
+	ImageURL        string                 `json:"imageURL,omitempty"`
+	Build           BuildTemplate          `json:"build,omitempty"`
+	KeystoreSecret  string                 `json:"keystoreSecret,omitempty"`
+	Database        DatabaseObject         `json:"database,omitempty"`
+	Jms             KieAppJmsObject        `json:"jms,omitempty"`
+	SmartRouter     SmartRouterObject      `json:"smartRouter,omitempty"`
+	Jvm             JvmObject              `json:"jvm,omitempty"`
 }
 
 // SmartRouterTemplate contains all the variables used in the yaml templates
 type SmartRouterTemplate struct {
+	OmitImageStream  bool   `json:"omitImageStream"`
 	Replicas         int32  `json:"replicas,omitempty"`
 	KeystoreSecret   string `json:"keystoreSecret,omitempty"`
 	Protocol         string `json:"protocol,omitempty"`
 	UseExternalRoute bool   `json:"useExternalRoute,omitempty"`
 	Image            string `json:"image,omitempty"`
 	ImageTag         string `json:"imageTag,omitempty"`
+	ImageURL         string `json:"imageURL,omitempty"`
 }
 
 // ReplicaConstants contains the default replica amounts for a component in a given environment type
@@ -436,31 +475,47 @@ type BuildTemplate struct {
 	KieServerContainerDeployment string                 `json:"kieServerContainerDeployment,omitempty"`
 	MavenMirrorURL               string                 `json:"mavenMirrorURL,omitempty"`
 	ArtifactDir                  string                 `json:"artifactDir,omitempty"`
+	// Extension image configuration which provides custom jdbc drivers to be used
+	// by KieServer.
+	ExtensionImageStreamTag          string `json:"extensionImageStreamTag,omitempty"`
+	ExtensionImageStreamTagNamespace string `json:"extensionImageStreamTagNamespace,omitempty"`
+	ExtensionImageInstallDir         string `json:"extensionImageInstallDir,omitempty"`
 }
 
 // CommonConfig variables used in the templates
 type CommonConfig struct {
 	ApplicationName    string `json:"applicationName,omitempty"`
-	ImageTag           string `json:"imageTag,omitempty"`
 	KeyStorePassword   string `json:"keyStorePassword,omitempty"`
 	AdminUser          string `json:"adminUser,omitempty"`
 	AdminPassword      string `json:"adminPassword,omitempty"`
 	DBPassword         string `json:"dbPassword,omitempty"`
 	AMQPassword        string `json:"amqPassword,omitempty"`
 	AMQClusterPassword string `json:"amqClusterPassword,omitempty"`
+	// Deprecated - Remove when 7.7.0 is the oldest version supported
 	ControllerPassword string `json:"controllerPassword,omitempty"`
-	ServerPassword     string `json:"serverPassword,omitempty"`
-	MavenPassword      string `json:"mavenPassword,omitempty"`
+	// Deprecated - Remove when 7.7.0 is the oldest version supported
+	ServerPassword string `json:"serverPassword,omitempty"`
+	// Deprecated - Remove when 7.7.0 is the oldest version supported
+	MavenPassword string `json:"mavenPassword,omitempty"`
 }
 
 // VersionConfigs ...
 type VersionConfigs struct {
-	APIVersion       string `json:"apiVersion,omitempty"`
-	ImageTag         string `json:"imageTag,omitempty"`
-	BrokerImage      string `json:"brokerImage,omitempty"`
-	BrokerImageTag   string `json:"brokerImageTag,omitempty"`
-	DatagridImage    string `json:"datagridImage,omitempty"`
-	DatagridImageTag string `json:"datagridImageTag,omitempty"`
+	APIVersion          string `json:"apiVersion,omitempty"`
+	OseCliImageURL      string `json:"oseCliImageURL,omitempty"`
+	OseCliComponent     string `json:"oseCliComponent,omitempty"`
+	BrokerImage         string `json:"brokerImage,omitempty"`
+	BrokerImageTag      string `json:"brokerImageTag,omitempty"`
+	BrokerImageURL      string `json:"brokerImageURL,omitempty"`
+	BrokerComponent     string `json:"brokerComponent,omitempty"`
+	DatagridImage       string `json:"datagridImage,omitempty"`
+	DatagridImageTag    string `json:"datagridImageTag,omitempty"`
+	DatagridImageURL    string `json:"datagridImageURL,omitempty"`
+	DatagridComponent   string `json:"datagridComponent,omitempty"`
+	MySQLImageURL       string `json:"mySQLImageURL,omitempty"`
+	MySQLComponent      string `json:"mySQLComponent,omitempty"`
+	PostgreSQLImageURL  string `json:"postgreSQLImageURL,omitempty"`
+	PostgreSQLComponent string `json:"postgreSQLComponent,omitempty"`
 }
 
 // AuthTemplate Authentication definition used in the template
@@ -521,11 +576,13 @@ type KieAppStatus struct {
 
 // PlatformService ...
 type PlatformService interface {
-	Create(ctx context.Context, obj runtime.Object) error
-	Delete(ctx context.Context, obj runtime.Object, opts ...client.DeleteOptionFunc) error
+	Create(ctx context.Context, obj runtime.Object, opts ...client.CreateOption) error
+	Delete(ctx context.Context, obj runtime.Object, opts ...client.DeleteOption) error
 	Get(ctx context.Context, key client.ObjectKey, obj runtime.Object) error
-	List(ctx context.Context, opts *client.ListOptions, list runtime.Object) error
-	Update(ctx context.Context, obj runtime.Object) error
+	List(ctx context.Context, list runtime.Object, opts ...client.ListOption) error
+	Update(ctx context.Context, obj runtime.Object, opts ...client.UpdateOption) error
+	Patch(ctx context.Context, obj runtime.Object, patch client.Patch, opts ...client.PatchOption) error
+	DeleteAllOf(ctx context.Context, obj runtime.Object, opts ...client.DeleteAllOfOption) error
 	GetCached(ctx context.Context, key client.ObjectKey, obj runtime.Object) error
 	ImageStreamTags(namespace string) imagev1.ImageStreamTagInterface
 	GetScheme() *runtime.Scheme
