@@ -14,7 +14,6 @@ import (
 	"github.com/RHsyseng/operator-utils/pkg/resource/read"
 	"github.com/RHsyseng/operator-utils/pkg/resource/write"
 	api "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v2"
-	"github.com/kiegroup/kie-cloud-operator/pkg/components"
 	"github.com/kiegroup/kie-cloud-operator/pkg/controller/kieapp/constants"
 	"github.com/kiegroup/kie-cloud-operator/pkg/controller/kieapp/shared"
 	routev1 "github.com/openshift/api/route/v1"
@@ -179,6 +178,11 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 	if shared.EnvVarSet(constants.DebugTrue, operator.Spec.Template.Spec.Containers[0].Env) {
 		debug = constants.DebugTrue
 	}
+
+	oauthImage := constants.OauthImageURL
+	if val, exists := os.LookupEnv(constants.OauthVar); exists {
+		oauthImage = val
+	}
 	sarString := fmt.Sprintf("--openshift-sar=%s", sar)
 	httpPort := int32(8080)
 	httpsPort := int32(8443)
@@ -193,9 +197,10 @@ func getPod(namespace string, image string, sa string, operator *appsv1.Deployme
 			Volumes:            []corev1.Volume{volume},
 			Containers: []corev1.Container{
 				{
-					Name:  "oauth-proxy",
-					Image: "registry.access.redhat.com/openshift3/oauth-proxy",
-					Ports: []corev1.ContainerPort{{Name: "public", ContainerPort: httpsPort}},
+					Name:            "oauth-proxy",
+					Image:           oauthImage,
+					ImagePullPolicy: operator.Spec.Template.Spec.Containers[0].ImagePullPolicy,
+					Ports:           []corev1.ContainerPort{{Name: "public", ContainerPort: httpsPort}},
 					Args: []string{
 						"--http-address=",
 						fmt.Sprintf("--https-address=:%d", httpsPort),
@@ -314,8 +319,12 @@ func getRole(namespace string) *rbacv1.Role {
 		Rules: []rbacv1.PolicyRule{
 			{
 				APIGroups: []string{api.SchemeGroupVersion.Group},
-				Resources: []string{"kieapps"},
-				Verbs:     components.Verbs,
+				Resources: []string{"*"},
+				Verbs:     []string{"*"},
+				/*
+					Resources: []string{"kieapps"},
+					Verbs:     components.Verbs,
+				*/
 			},
 		},
 	}
